MovesenseConnectionEvent class

A connection lifecycle event for a Movesense peripheral.

Constructors

MovesenseConnectionEvent({required MovesenseConnectionEventType type, String? address, String? serial, String? error})
const

Properties

address String?
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serial String?
final
type MovesenseConnectionEventType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited