CarpMovesenseFlutterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • CarpMovesenseFlutterPlatform
Implementers

Constructors

CarpMovesenseFlutterPlatform()
Constructs a CarpMovesenseFlutterPlatform.

Properties

connectionEvents Stream<MovesenseConnectionEvent>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanResults Stream<MovesenseDevice>
no setter

Methods

connect(String address) Future<void>
disconnect(String address) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request(MdsRequestMethod method, String uri, String contract) Future<MdsResponse>
startScan() Future<void>
stopScan() Future<void>
subscribe(String uri, String contract, {MdsSuccessCallback? onSubscribe, MdsErrorCallback? onSubscribeError, required MdsNotificationCallback onNotification, MdsErrorCallback? onSubscriptionError}) int
toString() String
A string representation of this object.
inherited
unsubscribe(int subscriptionId) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance CarpMovesenseFlutterPlatform
The default instance of CarpMovesenseFlutterPlatform to use.
getter/setter pair