MethodChannelCarpMovesenseFlutter class
Deprecated compatibility wrapper for code importing the template file.
Native communication now goes through generated Pigeon bindings. Keep this class only as a short-term migration aid; new code should use PigeonCarpMovesenseFlutter.
- Inheritance
-
- Object
- PlatformInterface
- CarpMovesenseFlutterPlatform
- PigeonCarpMovesenseFlutter
- MethodChannelCarpMovesenseFlutter
- Annotations
-
- @Deprecated('Use PigeonCarpMovesenseFlutter; this plugin no longer uses raw MethodChannel transport.')
Constructors
Properties
-
connectionEvents
→ Stream<
MovesenseConnectionEvent> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scanResults
→ Stream<
MovesenseDevice> -
no setterinherited
Methods
-
connect(
String address) → Future< void> -
inherited
-
disconnect(
String address) → Future< void> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
request(
MdsRequestMethod method, String uri, String contract) → Future< MdsResponse> -
inherited
-
startScan(
) → Future< void> -
inherited
-
stopScan(
) → Future< void> -
inherited
-
subscribe(
String uri, String contract, {MdsSuccessCallback? onSubscribe, MdsErrorCallback? onSubscribeError, required MdsNotificationCallback onNotification, MdsErrorCallback? onSubscriptionError}) → int -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
unsubscribe(
int subscriptionId) → Future< void> -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited